import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';
import 'dart:convert' show utf8;
import 'login_page.dart';
import 'pw_finding_page.dart';
import 'signup_page.dart';

/* 모바일 광고 */
import '../../plugins/admob.dart';

/* 설정 */
import '../../config/config.dart';

class IdFindingPage extends StatefulWidget {
  const IdFindingPage({Key? key}) : super(key: key);

  @override
  _IdFindingPageState createState() => _IdFindingPageState();
}

class _IdFindingPageState extends State<IdFindingPage> {
  final TextEditingController nicknameController = TextEditingController();
  final TextEditingController emailController = TextEditingController();

  String nicknameErrorMessage = '';
  /* 닉네임 오류 메시지 */
  String emailErrorMessage = '';
  /* 이메일 오류 메시지 */
  String foundIdMessage = '';
  /* 찾은 ID 안내 메시지 */
  String authId = '';

  Future<void> _findId(String nickname, String email) async {
    /* ID 찾기 요청 처리 */

    // Show loading indicator (로딩 인디케이터 표시)
    showDialog(
      context: context,
      barrierDismissible: false, 
      builder: (BuildContext context) {
        return const Center(child: CircularProgressIndicator());
      },
    );

    try {
      final response = await http
          .post(
            Uri.parse('https://eldsoft.com:8097/user/find/id'),
            headers: {
              'Content-Type': 'application/json',
            },
            body: jsonEncode({
              'nickname': nickname,
              'user_email': email,
            }),
          )
          .timeout(const Duration(seconds: 10)); // 10초 타임아웃 설정

      String responseBody = utf8.decode(response.bodyBytes);

      Navigator.of(context).pop(); // Close loading indicator (로딩 인디케이터 닫기)

      if (response.statusCode == 200) {
        final Map<String, dynamic> jsonResponse = jsonDecode(responseBody);

        // Reset messages (오류 메시지, ID 메시지 등)
        setState(() {
          nicknameErrorMessage = '';
          emailErrorMessage = '';
          foundIdMessage = '';
        });

        if (jsonResponse['response_info']['msg_title'] == '닉네임 확인') /* "닉네임 확인" */ {
          setState(() {
            nicknameErrorMessage = 'Please check your nickname again.'
                /* 닉네임을 다시 확인해주세요 */;
          });
        } else if (jsonResponse['response_info']['msg_title'] == '이메일 확인') /* "이메일 확인" */ {
          setState(() {
            emailErrorMessage = 'Please check your email again.'
                /* 이메일을 다시 확인해주세요 */;
          });
        } else if (jsonResponse['result'] == 'OK') {
          /* ID 찾기 성공 시 */
          setState(() {
            foundIdMessage = 'Your ID is ${jsonResponse['data']['user_id']}.'
                /* 당신의 ID는 ${jsonResponse['data']['user_id']} 입니다 */;
            authId = jsonResponse['data']['auth'];
          });
        } else {
          _showErrorDialog(
            jsonResponse['response_info']['msg_title'], 
            jsonResponse['response_info']['msg_content'], 
            'STAY',
          );
        }
      } else {
        // 요청 실패
        _showErrorDialog(
          'Error' 
          /* 오류 */, 
          'Request failed. Please contact the administrator.'
          /* 요청이 실패했습니다. 관리자에게 문의해주세요. */, 
          'STAY',
        );
      }
    } catch (e) {
      Navigator.of(context).pop();
      _showErrorDialog(
        'Error' 
        /* 오류 */, 
        'Request failed. Please contact the administrator.'
        /* 요청이 실패했습니다. 관리자에게 문의해주세요. */, 
        'STAY',
      );
    }
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  Future<void> _findAllId() async {
    /* ID 전체 찾기 요청 처리 */

    // Show loading indicator (로딩 인디케이터 표시)
    showDialog(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return const Center(child: CircularProgressIndicator());
      },
    );

    try {
      final response = await http
          .post(
            Uri.parse('https://eldsoft.com:8097/user/find/id/full'),
            headers: {
              'Content-Type': 'application/json',
            },
            body: jsonEncode({'auth': authId}),
          )
          .timeout(const Duration(seconds: 10)); // 10초 타임아웃

      String responseBody = utf8.decode(response.bodyBytes);

      Navigator.of(context).pop(); // Close loading indicator (로딩 인디케이터 닫기)

      if (response.statusCode == 200) {
        final Map<String, dynamic> jsonResponse = jsonDecode(responseBody);

        if (jsonResponse['result'] == 'OK') {
          // 성공
          _showSuccessDialog(
            'We have sent all IDs to your email.'
            /* 이메일로 전체 ID를 발송했습니다. */,
          );
        } else {
          _showErrorDialog(
            jsonResponse['response_info']['msg_title'], 
            jsonResponse['response_info']['msg_content'], 
            'STAY',
          );
        }
      } else {
        // 요청 실패
        _showErrorDialog(
          'Error'
          /* 오류 */, 
          'Request failed. Please contact the administrator.'
          /* 요청이 실패했습니다. 관리자에게 문의해주세요. */, 
          'STAY',
        );
      }
    } catch (e) {
      Navigator.of(context).pop();
      _showErrorDialog(
        'Error'
        /* 오류 */,
        'Request failed. Please contact the administrator.'
        /* 요청이 실패했습니다. 관리자에게 문의해주세요. */,
        'STAY',
      );
    }
  }

  void _showErrorDialog(String title, String content, String action) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: Colors.white,
          title: Text(title, style: const TextStyle(color: Colors.black)),
          content: Text(content, style: const TextStyle(color: Colors.black)),
          actions: <Widget>[
            Center(
              child: TextButton(
                style: TextButton.styleFrom(
                  backgroundColor: Colors.black,
                  foregroundColor: Colors.white,
                ),
                child: const Text('OK'
                  /* 확인 */),
                onPressed: () {
                  Navigator.of(context).pop();
                  if (action == 'LOGIN') {
                    Navigator.of(context).pop(); 
                    /* 로그인 페이지로 이동 */
                  }
                },
              ),
            ),
          ],
        );
      },
    );
  }

  void _showSuccessDialog(String message) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: const Text('Success' 
            /* 성공 */),
          content: Text(message),
          actions: <Widget>[
            TextButton(
              child: const Text('OK' 
                /* 확인 */),
              onPressed: () {
                Navigator.of(context).pop(); 
                Navigator.of(context).pop(); 
                /* 로그인 페이지로 이동 */
              },
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('ALL SCORE'
          /* ALL SCORE */,
          style: TextStyle(color: Colors.white)),
        backgroundColor: Colors.black,
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              if (foundIdMessage.isEmpty) ...[
                const Text(
                  'Find ID'
                  /* ID 찾기 */,
                  style: TextStyle(
                    fontSize: 24,
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                  ),
                ),
                const SizedBox(height: 32),
                TextField(
                  controller: nicknameController,
                  decoration: InputDecoration(
                    labelText: 'Nickname'
                    /* 닉네임 */,
                    labelStyle: const TextStyle(color: Colors.black),
                    border: const OutlineInputBorder(),
                    focusedBorder: const OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.black, width: 2.0),
                    ),
                  ),
                ),
                if (nicknameErrorMessage.isNotEmpty)
                  Padding(
                    padding: const EdgeInsets.only(top: 8.0),
                    child: Text(
                      nicknameErrorMessage,
                      style: const TextStyle(color: Colors.red),
                    ),
                  ),
                const SizedBox(height: 16),
                TextField(
                  controller: emailController,
                  decoration: InputDecoration(
                    labelText: 'Email'
                    /* 이메일 */,
                    labelStyle: const TextStyle(color: Colors.black),
                    border: const OutlineInputBorder(),
                    focusedBorder: const OutlineInputBorder(
                      borderSide: BorderSide(color: Colors.black, width: 2.0),
                    ),
                  ),
                ),
                if (emailErrorMessage.isNotEmpty)
                  Padding(
                    padding: const EdgeInsets.only(top: 8.0),
                    child: Text(
                      emailErrorMessage,
                      style: const TextStyle(color: Colors.red),
                    ),
                  ),
                const SizedBox(height: 16),
                ElevatedButton(
                  onPressed: () {
                    _findId(nicknameController.text, emailController.text);
                  },
                  style: ElevatedButton.styleFrom(
                    backgroundColor: Colors.black,
                    foregroundColor: Colors.white,
                  ),
                  child: const Text('Find ID'
                    /* ID 찾기 */),
                ),
              ] else ...[
                // ID 찾기 성공 시 메시지
                Text(
                  foundIdMessage,
                  style: const TextStyle(fontSize: 20, color: Colors.black),
                ),
                const SizedBox(height: 16),
                ElevatedButton(
                  onPressed: () {
                    _findAllId(); 
                    /* ID 전체 찾기 버튼 */
                  },
                  style: ElevatedButton.styleFrom(
                    backgroundColor: Colors.black,
                    foregroundColor: Colors.white,
                  ),
                  child: const Text('Find All IDs'
                    /* ID 전체 찾기 */),
                ),
              ],
              const SizedBox(height: 16),
              TextButton(
                onPressed: () {
                  Navigator.pop(context);
                  /* 로그인 페이지로 이동 */
                },
                child: const Text('Login'
                  /* 로그인 */,
                  style: TextStyle(color: Colors.black)),
              ),
              TextButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(builder: (context) => const PwFindingPage()),
                  );
                },
                child: const Text('Find PW'
                  /* PW 찾기 */,
                  style: TextStyle(color: Colors.black)),
              ),
              TextButton(
                onPressed: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(builder: (context) => const SignUpPage()),
                  );
                },
                child: const Text('Sign Up'
                  /* 회원가입 */,
                  style: TextStyle(color: Colors.black)),
              ),
            ],
          ),
        ),
      ),

      bottomNavigationBar: AdBannerWidget()
      /* (3) 하단 광고 영역 */,
    );
  }
}
